<?php
/** Emiliàn (Emiliàn)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Reder
 */

$fallback = 'it';

$messages = array(
# Dates
'sun' => 'Dum',
'mon' => 'Lün',
'tue' => 'Mär',
'wed' => 'Mer',
'thu' => 'Giu',
'fri' => 'Van',
'sat' => 'Sab',
'january' => 'Znär',
'february' => 'Farvär',
'march' => 'März',
'april' => 'April',
'may_long' => "Magg'",
'june' => 'Giügn',
'july' => 'Lüi',
'august' => 'Agust',
'september' => 'Steimbar',
'october' => 'Uttubar',
'november' => 'Nueimbar',
'december' => 'Dzeimbar',
'january-gen' => 'Znär',
'february-gen' => 'Farvär',
'march-gen' => 'März',
'april-gen' => 'April',
'may-gen' => "Magg'",
'june-gen' => 'Giügn',
'july-gen' => 'Lüi',
'august-gen' => 'Agust',
'september-gen' => 'Steimbar',
'october-gen' => 'Uttubar',
'november-gen' => 'Nueimbar',
'december-gen' => 'Dzeimbar',
'jan' => 'Znä',
'feb' => 'Far',
'mar' => 'Mär',
'apr' => 'Apr',
'may' => 'Mag',
'jun' => 'Giü',
'jul' => 'Lüi',
'aug' => 'Agu',
'sep' => 'Ste',
'oct' => 'Utt',
'nov' => 'Nue',
'dec' => 'Dze',

# Categories related messages
'hidden-categories' => '{{PLURAL:$1|Categuria nascost|Categuri nascost}}',

'about' => 'Informaziun',
'cancel' => ' 
Cancellä',
'mytalk' => 'Le mé discüssion',
'navigation' => 'Navigazion',
'and' => '&#32;e',

# Cologne Blue skin
'qbfind' => 'Trov',
'qbedit' => 'Mudifich',
'qbpageoptions' => "Opzion d'la pàgina",
'qbmyoptions' => 'Le mé pàgin',
'qbspecialpages' => 'Pàgin speciäl',
'faq' => 'Dumand frequeint',

# Vector skin
'vector-action-delete' => 'Cancellä',
'vector-action-move' => 'Spusta',
'vector-action-protect' => "Prutegg'",
'vector-view-create' => 'Creä',
'vector-view-edit' => 'Mudifich',
'vector-view-history' => 'Väda la storia',
'vector-view-view' => "Legg'",
'vector-view-viewsource' => 'Vadä la surgìnt',
'actions' => 'Azion',
'namespaces' => 'Namespace',
'variants' => 'Variänt',

'errorpagetitle' => 'Errur',
'tagline' => 'Da {{SITENAME}}',
'help' => 'Aiüt',
'search' => 'Cercä',
'searchbutton' => 'Cercä',
'go' => 'Vé',
'searcharticle' => 'Vé',
'history' => "Storia d'la pàgina",
'history_short' => 'Storia',
'permalink' => 'Link permaneint',
'print' => 'Stampa',
'view' => 'Vada',
'edit' => 'Mudifich',
'create' => 'Creä',
'delete' => 'Cancellä',
'deletethispage' => 'Cancellä custa pàgina ché',
'undelete_short' => 'Recuperä {{PLURAL:$1|una revision|$1 revision}}',
'viewdeleted_short' => 'Vadä {{PLURAL:$1|una mudfich cancellät|$1 mudfich cancellät}}',
'protect' => "Prutegg'",
'protect_change' => 'Cambia',
'protectthispage' => "Prutegg' custa pàgina ché",
'unprotect' => 'Cambiä la prutezion',
'unprotectthispage' => 'Cambiä la prutezion par custa pàgina ché',
'newpage' => 'Pàgina növa',
'talkpage' => 'Pàgina ad discüssion',
'talkpagelinktext' => 'Discüssion',
'specialpage' => 'Pàgina speciäl',
'personaltools' => 'Strümeint parsunäl',
'postcomment' => 'Sezion növa',
'articlepage' => 'Vadä la pàgina ad contenüt',
'talk' => 'Discüssion',
'views' => 'Visit',
'toolbox' => 'Strümeint',
'userpage' => "Vadä la pàgina ad l'uteint",
'projectpage' => 'Vadä la pàgina dal prugett',
'imagepage' => 'Vadä la pàgina dal file',
'mediawikipage' => "Vadä al messagg'",
'templatepage' => 'Vadä al template',
'viewhelppage' => "Vadä la pàgina d'aiüt",
'categorypage' => 'Vadä la categoria',
'viewtalkpage' => 'Vadä la discüssion',
'otherlanguages' => 'Ätar leingav',
'redirectedfrom' => '(Reindirizzameint da <b>$1</b>)',
'redirectpagesub' => 'Pàgina ad reindirizzameint',
'lastmodifiedat' => "Ültim mudifich d'la pàgina: $2, $1.",
'viewcount' => "Custa pàgina ché l'è stata letta {{PLURAL:$1|vüna volta|$1 volte}}.",
'protectedpage' => 'Pàgina bluccä',
'jumpto' => 'Andä a',
'jumptonavigation' => 'navigazion',
'jumptosearch' => 'cercä',
'pool-queuefull' => "La cua dal pool l'è piena",
'pool-errorunknown' => 'Errur mia cugnussü',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite' => 'Infurmazion su {{SITENAME}}',
'aboutpage' => 'Project:Infurmäzion',
'copyright' => "Contenüt suggètt a licinza d'üs $1.",
'copyrightpage' => '{{ns:project}}:Copyright',
'currentevents' => 'Eveint curreint',
'currentevents-url' => 'Project:Eveint curreint',
'disclaimers' => 'Informazion legäl',
'disclaimerpage' => 'Project:Avvartenza generäl',
'edithelp' => 'Libar di spiegazión',
'edithelppage' => 'Help:Mudifich',
'helppage' => "Help:Tütt l'argumeint",
'mainpage' => 'Prima pàgina',
'mainpage-description' => 'Pàgina principäl',
'policy-url' => 'Project:Policy',
'portal' => "Purtäda d'la cumünitä",
'portal-url' => "Project:Purtäda d'la cumünitä",
'privacy' => "Legg' l'informazion parsunäl",

'ok' => 'OK',
'newmessageslink' => "növ messagg'",
'editsection' => 'cambi',
'editold' => 'mudifich',
'viewsourceold' => 'vadä la surgìnt',
'editlink' => 'mudifich',
'viewsourcelink' => 'vadä la surgìnt',
'editsectionhint' => 'Mudifich la seziòn: $1',
'toc' => 'Indez',
'showtoc' => 'mustra',
'hidetoc' => 'nascond',
'collapsible-collapse' => 'Comprim',
'collapsible-expand' => 'Espand',
'thisisdeleted' => 'Vadä o ripristinä $1?',
'viewdeleted' => 'Vadä $1?',
'restorelink' => '{{PLURAL:$1|vüna mudfich cancellät|$1 mudfich cancellät}}',
'feedlinks' => 'Feed:',
'feed-invalid' => "La mudalitä ad sottoscrizion dal feed l'è mia valid.",
'feed-unavailable' => 'I feed al son mia dispunibil',
'site-rss-feed' => 'Emissiòn RSS ad $1',
'site-atom-feed' => 'Emission Atom ad $1',
'page-rss-feed' => 'Emissiòn RSS par $1',
'page-atom-feed' => 'Emission Atom par $1',
'red-link-title' => "$1 (la pàgina a l'esist mia)",
'sort-descending' => 'Ordinamient decrescent',
'sort-ascending' => 'Ordinamient cresceint',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Pàgina',
'nstab-user' => 'Pàgina uteint',
'nstab-media' => 'File multimediäl',
'nstab-special' => 'Pàgina speciäl',
'nstab-project' => 'Pàgina ad sërvizi',
'nstab-image' => 'Immàgin',
'nstab-mediawiki' => "Messagg'",
'nstab-template' => 'Mudell',
'nstab-help' => 'Aiüt',
'nstab-category' => 'Categuria',

# General errors
'error' => 'Errur',
'databaseerror' => 'Errur dal database',
'readonly' => 'Database bluccä',
'missingarticle-rev' => '(revision n°: $1)',
'missingarticle-diff' => '(Diff: $1, $2)',
'internalerror' => 'Errur interiur',
'internalerror_info' => 'Errur interiur: $1',
'viewsource' => 'Vadä la surgìnt',
'viewsource-title' => 'Vadä la surgìnt ad $1',

# Login and logout pages
'yourname' => 'Nom uteint:',
'yourpassword' => 'Password:',
'yourpasswordagain' => 'Ripett la password:',
'login' => 'Enträ',
'nav-login-createaccount' => 'Enträ / Creä un account',
'userlogin' => 'Enträ / Creä un account',
'userloginnocreate' => 'Enträ',
'logout' => 'Üscì',
'userlogout' => 'Üscì',
'notloggedin' => 'Si mia enträ',
'nologinlink' => 'Creä un cunt',
'createaccount' => 'Creä cunt',
'gotaccountlink' => 'Enträ',
'createaccountmail' => 'Via e-mail',
'createaccountreason' => 'Mutiv:',
'loginerror' => 'Errur ad enträ',
'accountcreated' => 'Account creä',
'loginlanguagelabel' => 'Leingua: $1',

# Change password dialog
'resetpass' => 'Cambiä la password',
'oldpassword' => "Vecc' password:",
'newpassword' => 'Növa password:',
'resetpass-submit-loggedin' => 'Cambiä la password',
'resetpass-submit-cancel' => 'Cancellä',
'resetpass-temp-password' => 'Password tempural:',

# Special:PasswordReset
'passwordreset' => 'Cambiä la password',
'passwordreset-legend' => 'Cambiä la password',
'passwordreset-username' => 'Nom uteint:',
'passwordreset-domain' => 'Dumini:',

# Edit page toolbar
'bold_sample' => 'Grassètt',
'italic_sample' => 'Cursìv',
'media_tip' => 'Cullegameint al file',

# Edit pages
'summary' => 'Summari:',
'savearticle' => 'Sälv la pàgina',
'preview' => 'Vadä prima',
'showpreview' => "Vadä l'antepeima",
'showdiff' => 'Vadä li cambiameint',
'blockedtitle' => 'Uteint bluccä',
'newarticle' => '(Növ)',
'note' => "'''Nota:'''",
'editing' => 'Mudifich ad $1',
'editingsection' => 'Mudifich ad $1 (sezion)',
'editingcomment' => 'Mudifich ad $1 (növ sezion)',
'editconflict' => 'Conflitt ad mudifich: $1',
'yourtext' => 'Al tò test',
'yourdiff' => 'Differeinz',
'template-protected' => '(prutett)',
'template-semiprotected' => '(mézz-prutett)',
'log-fulllog' => 'Vadä al log cumplet',
'edit-conflict' => 'Conflitt ad mudifich.',

# History pages
'viewpagelogs' => 'Vadä li log ad custa pàgina ché',
'currentrev' => 'Ültima version',
'currentrev-asof' => 'Ültima version dle $1',
'revisionasof' => 'Version dle $1',
'revision-info' => 'Version dle $1, avtur: $2',
'previousrevision' => "← Version piö vecc'",
'nextrevision' => 'Versiòn piö növ →',
'currentrevisionlink' => 'Ültima version',
'cur' => 'curr',
'next' => 'succ',
'last' => 'prec',
'page_first' => 'prima',
'page_last' => 'ültim',

# Revision feed
'history-feed-item-nocomment' => '$1 al $2',

# Revision deletion
'rev-delundel' => 'vadä/anscönd',
'revdelete-radio-set' => 'Sì',
'revdelete-radio-unset' => 'No',
'revdelete-reasonotherlist' => 'Ätar ragion',

# Merge log
'revertmerge' => "Annullä l'ünion",

# Diffs
'lineno' => 'Riga $1:',
'editundo' => 'cancellä',

# Search results
'searchresults' => "Risultät d'la ricerch",
'searchresults-title' => 'Risultät d\'la ricerch ad "$1"',
'viewprevnext' => 'Väda ($1 {{int:pipe-separator}} $2) ($3).',
'searchprofile-articles' => 'Pàgin ad cuntinüt',
'searchprofile-images' => 'Multimëdi',
'searchprofile-everything' => 'Tütt',
'searchprofile-advanced' => 'Avanzät',
'searchprofile-articles-tooltip' => 'Cercä in $1',
'searchprofile-project-tooltip' => 'Cercä in $1',
'searchprofile-images-tooltip' => 'Cercä immàgin',
'search-result-size' => '$1 ({{PLURAL:$2|1 parola|$2 paroli}})',
'search-redirect' => '(redirect $1)',
'search-section' => '(sezion $1)',
'search-interwiki-caption' => 'Prugett fradel',
'search-interwiki-default' => 'Risültä da $1:',
'search-interwiki-more' => '(ätar)',
'searchall' => 'tütt',
'powersearch-toggleall' => 'Tütt',
'powersearch-togglenone' => 'Ansöin',

# Preferences page
'preferences' => 'Prefereinz',
'mypreferences' => 'Al me prefereinz',
'prefs-edits' => 'Nümar ad mudifich:',
'prefsnologin' => 'Si mia enträ',
'changepassword' => 'Cambiä la password',
'prefs-skin' => 'Skin',
'skin-preview' => 'Vadä prima',
'datedefault' => 'Ansiön prefereinz',
'prefs-beta' => 'Funzionalitä beta',
'saveprefs' => 'Salvä',
'prefs-editing' => 'Mudificä',
'rows' => 'Righe',
'searchresultshead' => 'Cercä',
'timezoneregion-africa' => 'Africa',
'timezoneregion-america' => 'América',
'timezoneregion-antarctica' => 'Antartide',
'timezoneregion-arctic' => 'Artide',
'timezoneregion-asia' => 'Asia',
'timezoneregion-atlantic' => 'Ucean Atlantich',
'timezoneregion-australia' => 'Australia',
'timezoneregion-europe' => 'Europa',
'timezoneregion-indian' => 'Ucean Indian',
'timezoneregion-pacific' => 'Ucean Pacifich',
'youremail' => 'E-mail:',
'username' => 'Nom uteint',
'uid' => 'ID uteint',
'prefs-memberingroups' => 'Membar {{PLURAL:$1|dal grüpp|dei grüpp}}:',
'yourrealname' => 'Nom ver:',
'yourlanguage' => 'Leingua',
'email' => 'E-mail',

# Groups
'group' => 'Grüpp:',
'group-user' => 'Uteint',
'group-autoconfirmed' => 'Uteint autoconvalidät',
'group-bot' => 'Bot',
'group-sysop' => 'Amministradór',
'group-bureaucrat' => 'Bürocrat',
'group-suppress' => 'Oversight',
'group-all' => '(tütt)',

'group-user-member' => '{{GENDER:$1|uteint}}',
'group-autoconfirmed-member' => '{{GENDER:$1|uteint autoconvalidät}}',
'group-bot-member' => '{{GENDER:$1|bot}}',
'group-sysop-member' => '{{GENDER:$1|amministradór}}',
'group-bureaucrat-member' => '{{GENDER:$1|bürocrat}}',
'group-suppress-member' => '{{GENDER:$1|oversight}}',

'grouppage-user' => '{{ns:project}}:Uteint',
'grouppage-autoconfirmed' => '{{ns:project}}:Uteint autoconvalidät',
'grouppage-bot' => '{{ns:project}}:Bot',
'grouppage-sysop' => '{{ns:project}}:Amministradór',
'grouppage-bureaucrat' => '{{ns:project}}:Bürocrat',
'grouppage-suppress' => '{{ns:project}}:Oversight',

# Rights
'right-read' => "Legg' pàgin",
'right-edit' => 'Mudifich pàgin',

# Associated actions - in the sentence "You do not have permission to X"
'action-read' => "legg' custa pàgina ché",
'action-edit' => 'mudifch custa pàgina ché',
'action-createpage' => 'creä pàgin',
'action-move' => 'spustä custa pàgina ché',
'action-movefile' => 'spustä cust file ché',
'action-upload' => 'caricä cust file ché',
'action-delete' => 'cancellä custa pàgina ché',

# Recent changes
'recentchanges' => 'Ültim cambiameint',
'rcshowhidebots' => '$1 i bot',
'rcshowhidemine' => '$1 le mé mudifich',
'diff' => 'diff',
'hist' => 'cron',
'hide' => 'Nascond',
'show' => 'mustra',
'minoreditletter' => 'm',
'newpageletter' => 'N',
'boteditletter' => 'b',
'number_of_watching_users_pageview' => '[usservä da {{PLURAL:$1|vün uteint|$1 uteint}}]',
'rc_categories_any' => 'Qualsía',

# Upload
'upload' => 'Cärga un file',

'license' => 'Licinza:',
'license-header' => 'Licinza',
'nolicense' => 'Ansöna licinza seleziunä',

# Special:ListFiles
'listfiles_date' => 'Data',
'listfiles_name' => 'Nom',
'listfiles_user' => 'Uteint',

# File description page
'file-anchor-link' => 'Immàgin',
'filehist' => 'Storia dal file',
'filehist-current' => 'curreint',
'filehist-datetime' => 'Data/Ura',
'filehist-thumb' => 'Miniadüra',
'filehist-user' => 'Uteint',
'filehist-dimensions' => 'Dimension',
'filehist-comment' => 'Uggett',
'imagelinks' => 'Cullegameint al file',

# File deletion
'filedelete-submit' => 'Cancellä',

# Random page
'randompage' => 'Una pàgina a cäs',

'brokenredirects-edit' => 'cambi',

# Miscellaneous special pages
'nbytes' => '$1 {{PLURAL:$1|byte|byte}}',
'newpages' => 'Pàgin növ',
'move' => 'Spusta',

# Book sources
'booksources-go' => 'Vé',

# Special:AllPages
'alphaindexline' => 'da $1 a $2',
'allpagessubmit' => 'Vé',

# Special:ListUsers
'listusers-submit' => 'Mustra',

# Special:ListGroupRights
'listgrouprights-group' => 'Grüpp',

# Email user
'emailfrom' => 'Da:',
'emailto' => 'A:',
'emailsubject' => 'Uggett:',
'emailmessage' => "Messagg'",

# Watchlist
'mywatchlist' => 'Le mé üsservat speciäl',
'watchlistfor2' => "Dall'uteint $1 $2",
'watchnologin' => 'Si mia enträ',
'watch' => 'Vadä',
'watchthispage' => 'Vadä custa pàgina ché',
'unwatch' => "N'la vadär piö",

'created' => 'creät',
'changed' => 'mudifegat',

# Delete
'delete-confirm' => 'Cancellä "$1"',
'delete-legend' => 'Cancellä',

# Rollback
'rollback_short' => 'Turne indré',
'rollbacklink' => 'Avé indré la mudifech ad prima',
'rollbackfailed' => 'Si mia riussì a turnä indré',

# Protect
'pagesize' => '(byte)',

# Restrictions (nouns)
'restriction-edit' => 'Mudifich',
'restriction-move' => 'Spusta',
'restriction-create' => 'Creä',
'restriction-upload' => 'Caricä',

# Undelete
'undeletelink' => 'vada/turna indré',
'undeleteviewlink' => 'vada',
'undelete-show-file-submit' => 'Sì',

# Namespace form on various pages
'namespace' => 'Namespace:',
'blanknamespace' => '(Principäl)',

# Contributions
'contributions' => "Contribüdi de l'uteint",
'contributions-title' => 'Contribüdi ed $1',
'mycontris' => 'Le mé contribüdi',
'contribsub2' => 'Par $1 ($2)',
'uctop' => '(ültim par la pàgin)',

'sp-contributions-submit' => 'Cercä',

# What links here
'whatlinkshere-page' => 'Pàgina:',
'whatlinkshere-links' => '← cullegameint',

# Block/unblock
'block' => "Bluccä l'uteint",
'unblock' => "Sbluccä l'uteint",
'blockip' => "Bluccä l'uteint",
'blockip-title' => "Bluccä l'uteint",
'blockip-legend' => "Bluccä l'uteint",
'ipbotheroption' => 'ätar',
'ipb-unblock-addr' => 'Sbluccä $1',
'unblockip' => "Sbluccä l'uteint",
'blocklist' => 'Uteint bluccä',
'ipblocklist-submit' => 'Cercä',
'ipblocklist-otherblocks' => 'Ätar {{PLURAL:$1|blocc|blocc}}',
'blocklink' => 'blocc',
'unblocklink' => 'sblocc',
'change-blocklink' => 'cambiä al blocc',
'contribslink' => 'cuntribüti',
'unblocklogentry' => "l'à sbluccä $1",

# Move page
'move-page' => 'Spustameint ad $1',
'move-page-legend' => 'Spustä la pàgina',
'movearticle' => 'Spustä la pàgina:',
'movenologin' => 'Si mia enträ',
'movepagebtn' => 'Spustä la pàgina',
'movelogpage' => 'Spustameint',
'revertmove' => 'Turné indré',

# Export
'export-submit' => 'Esporta',

# Namespace 8 related
'allmessages-filter-all' => 'Tütt',
'allmessages-language' => 'Leingua:',
'allmessages-filter-submit' => 'Vé',

# Thumbnails
'thumbnail-more' => 'Allargä',

# Special:Import
'import-upload-filename' => 'Nom dal file:',
'import-comment' => 'Uggett:',
'import-upload' => 'Caricä dat XML',

# Tooltip help for the actions
'tooltip-pt-logout' => 'Üscì',
'tooltip-ca-move' => 'Spustä custa pàgina ché',
'tooltip-search' => 'Cercä deintar ad {{SITENAME}}',
'tooltip-p-logo' => 'Väda la pàgina principäl',
'tooltip-n-mainpage' => 'Väda la pàgina principäl',
'tooltip-n-mainpage-description' => 'Väda la pàgina principäl',
'tooltip-n-randompage' => 'Fa vëd una pàgina a cäs',
'tooltip-n-help' => 'Pàgin di aiüt',
'tooltip-t-upload' => 'Cärag file multimediäl',
'tooltip-ca-nstab-project' => 'Vadä la pàgina dal prugett',
'tooltip-ca-nstab-image' => ' 
Vadä la pàgina dal file',
'tooltip-ca-nstab-template' => 'Väda la template',
'tooltip-ca-nstab-help' => "Vadä la pàgina d'aiüt",
'tooltip-ca-nstab-category' => "Vadä la pàgina d'la categoria",
'tooltip-save' => 'Salvä li tò cambiameint',

# Attribution
'others' => 'ätar',

# Info page
'pageinfo-header-edits' => 'Mudifich',
'pageinfo-views' => 'Nümar ad visit',
'pageinfo-watchers' => 'Numar ad visitador',
'pageinfo-edits' => 'Nümar ad mudifich',
'pageinfo-authors' => 'Nümar ad devers autor',

# Browsing diffs
'previousdiff' => "← Mudifich piö vecc'",
'nextdiff' => 'Mudifich piö növa →',

# Media information
'file-info-gif-looped' => 'ciclich',
'file-info-png-looped' => 'ciclich',

# Special:NewFiles
'newimages-legend' => 'Nom dal file',
'showhidebots' => '($1 i bot)',
'ilsubmit' => 'Cercä',
'bydate' => 'par data',

# Video information, used by Language::formatTimePeriod() to format lengths in the above messages
'ago' => '$1 fa',

# Metadata
'metadata' => 'Metadat',

# Exif tags
'exif-exposuretime-format' => '$1 s ($2)',
'exif-gpsareainformation' => "Nom d'la zona GPS",
'exif-gpsdatestamp' => 'Data GPS',
'exif-source' => 'Font',
'exif-languagecode' => 'Leingva',
'exif-iimcategory' => 'Categuria',
'exif-identifier' => 'Identificativ',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'tütt',
'namespacesall' => 'tütt',
'monthsall' => 'tütt',
'limitall' => 'tütt',

# Delete conflict
'recreate' => 'Creä ad növ',

# action=purge
'confirm_purge_button' => 'OK',

# action=watch/unwatch
'confirm-watch-button' => 'OK',
'confirm-unwatch-button' => 'OK',

# Multipage image navigation
'imgmultigo' => 'Vé!',
'imgmultigoto' => "Vé in s'la pàgina $1",

# Table pager
'ascending_abbrev' => 'cresc',
'descending_abbrev' => 'decresc',
'table_pager_first' => 'Prima pàgina',
'table_pager_last' => 'Ültima pàgina',
'table_pager_limit_submit' => 'Vé',

# Watchlist editor
'watchlistedit-raw-titles' => 'Titul:',

# Special:Version
'version' => 'Version',
'version-specialpages' => 'Pàgin speciäl',
'version-other' => 'Ätar',
'version-version' => '(Version $1)',
'version-license' => 'Licinza',
'version-poweredby-others' => 'ätar',

# Special:FileDuplicateSearch
'fileduplicatesearch-filename' => 'Nom dal file:',
'fileduplicatesearch-submit' => 'Cercä',

# Special:SpecialPages
'specialpages' => 'Pàgin speciäl',

# Special:Tags
'tags-edit' => 'mudifich',

# Special:ComparePages
'compare-page1' => 'Pàgina 1',
'compare-page2' => 'Pàgina 2',
'compare-rev1' => 'Revisiòn 1',
'compare-rev2' => 'Revisiòn 2',

# HTML forms
'htmlform-reset' => 'Turna indré cul la mudifich',
'htmlform-selectorother-other' => 'Ätar',

# New logging system
'rightsnone' => '(ansöin)',

# Feedback
'feedback-subject' => 'Uggett:',
'feedback-message' => "Messagg':",
'feedback-cancel' => 'Cancellä',

);
